! source file: /usr/local/models/UVic_ESCM/2.8/source/embm/winds.F
      subroutine add_awind (is, ie, js, je)

!=======================================================================
!     update winds

!     based on code by: A. Fanning and M. Eby
!=======================================================================

      return
      end

      subroutine calc_awind (is, ie, js, je)

!=======================================================================
!     calculate anomalous pressure and geostrophic wind

!     based on code by: A. Fanning, A. Scmittner and M. Eby
!=======================================================================

      return
      end
